<?php
namespace Elementor;
if( !defined( 'ABSPATH' ) ) exit; // No access of directly access

class Premium_Counter_Down_Widget extends Widget_Base {


	public function get_name() {
		return 'premium-countdown-timer';
	}

	public function get_title() {
		return esc_html__( 'Premium CountDown', 'premium_elementor' );
	}

	public function get_icon() {
		return 'pa-pa-count';
	}

	public function get_script_depends() {
		return [ 'countdowntimer.js' ];
	}

	public function get_categories() {
		return [ 'premium-elements' ];
	}

    // Adding the controls fields for the premium countdown
    // This will controls the animation, colors and background, dimensions etc
	protected function _register_controls() {
		$this->start_controls_section(
			'pcdt-global-settings',
			[
				'label'		=> esc_html__( 'Premium CountDown Timer', 'premium_elementor' )
			]
		);

		$this->add_control(
			'pcdt-style',
		  	[
		     	'label'			=> esc_html__( 'CountDown Style', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::SELECT,
		     	'options' 		=> [
		     		'd-u-s' => esc_html__( 'Digit and unit side by side', 'premium_elementor' ),
		     		'd-u-u' => esc_html__( 'Digit and unit up and down', 'premium_elementor' ),
		     	],
		     	'default'		=> 'd-u-s'
		  	]
		);

		$this->add_control(
			'pcdt_date_time',
		  	[
		     	'label'			=> esc_html__( 'Target Data and Time', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::DATE_TIME,
		     	'picker_options'	=> [
		     		'format' => 'Y/m/d H:m:s'
		     	],
		     	'default' => date( "Y/m/d H:m:s", strtotime("+ 1 day") ),
				'description' => esc_html__( 'Example Date: 2020-01-22 01:30', 'boosted-elements-progression' )
		  	]
		);

		$this->add_control(
			'pcdt_s_u_time',
			[
				'label' 		=> esc_html__( 'Countdown Timer Depends', 'premium_elementor' ),
				'type' 			=> Controls_Manager::SELECT,
				'options' 		=> [
					'wp-time'			=> esc_html__('WordPress Default', 'premium_elementor' ),
					'user-time'			=> esc_html__('User system', 'premium_elementor' )
				],
				'default'		=> 'wp-time',
				'description'	=> esc_html__('This will set current time from the options', 'premium_elementor')
			]
		);

		$this->add_control(
			'pcdt_units',
		  	[
		     	'label'			=> esc_html__( 'Select Time Units', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::SELECT2,
				'description' => esc_html__('Select Time Units To Display In Countdown Timer', 'premium_elementor' ),
				'options'		=> [
					'Y'     => esc_html__( 'Years', 'premium_elementor' ),
					'O'     => esc_html__( 'Month', 'premium_elementor' ),
					'W'     => esc_html__( 'Week', 'premium_elementor' ),
					'D'     => esc_html__( 'Day', 'premium_elementor' ),
					'H'     => esc_html__( 'Hours', 'premium_elementor' ),
					'M'     => esc_html__( 'Minutes', 'premium_elementor' ),
					'S' 	=> esc_html__( 'Second', 'premium_elementor' ),
				],
				'default' 		=> [
					'D',
					'H',
					'M',
					'S'
				],
				'multiple'		=> true,
				'separator'		=> 'after'
		  	]
		);

		$this->add_responsive_control(
			'separator_width',
			[
				'label'			=> esc_html__( 'Separator Width', 'premium_elementor' ),
				'type' 			=> Controls_Manager::SLIDER,
				'default' 		=> [
					'size' => 30,
				],
				'range' 		=> [
					'px' 	=> [
						'min' => 0,
						'max' => 200,
					]
				],
				'selectors'		=> [
					'{{WRAPPER}} .countdown .pre_countdown-section' => 'margin-right: {{SIZE}}{{UNIT}};'
				]
			]
		);

		$this->add_control(
			'timer_border_style',
			[
				'label' 		=> esc_html__( 'Timer digit Border Style', 'premium_elementor' ),
				'type' 			=> Controls_Manager::SELECT,
				'options' 		=> [
					'none'			=> esc_html__('None', 'premium_elementor' ),
					'solid'			=> esc_html__('Solid', 'premium_elementor' ),
					'dashed'		=> esc_html__('Dashed', 'premium_elementor' ),
					'dotted'		=> esc_html__('Dotted', 'premium_elementor' ),
					'double'		=> esc_html__('Double', 'premium_elementor' ),
					'inset'			=> esc_html__('Inset', 'premium_elementor' ),
					'outset'		=> esc_html__('Outset', 'premium_elementor' ),
				],
				'default'		=> 'none',

			]
		);

		$this->add_responsive_control(
			'digit_border_size',
			[
				'label'			=> esc_html__( 'Digit Border Size', 'premium_elementor' ),
				'type' 			=> Controls_Manager::SLIDER,
				'default' 		=> [
					'size' => 2,
				],
				'range' 		=> [
					'px' 	=> [
						'min' => 0,
						'max' => 50,
					]
				],
				'condition' => [
					'timer_border_style!' => 'none'
				],
				'selectors'		=> [
					'{{WRAPPER}} .border .pre_countdown-section .pre_countdown-amount' => 'border-width: {{SIZE}}{{UNIT}};'
				]
			]
		);


		$this->add_control(
			'digit_border_color',
			[
				'label' 		=> esc_html__( 'Digit Border Color', 'premium_elementor' ),
				'type' 			=> Controls_Manager::COLOR,
				'scheme' 		=> [
				    'type' 	=> Scheme_Color::get_type(),
				    'value' => Scheme_Color::COLOR_2,
				],
				'condition' => [
					'timer_border_style!' => 'none'
				],
				'selectors'		=> [
					'{{WRAPPER}} .border .pre_countdown-section .pre_countdown-amount' => 'border-color: {{VALUE}};'
				]
			]
		);


		$this->add_responsive_control(
			'digit_border_radius',
			[
				'label'			=> esc_html__( 'Digit Border Radius', 'premium_elementor' ),
				'type' 			=> Controls_Manager::SLIDER,
				'default' => [
					'size' => 2,
				],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'condition' => [
					'timer_border_style!' => 'none'
				],
				'selectors'		=> [
					'{{WRAPPER}} .border .pre_countdown-section .pre_countdown-amount' => 'border-radius: {{SIZE}}%;'
				]
			]
		);


		$this->add_control(
			'timer_digit_bg_color',
			[
				'label' 		=> esc_html__( 'Digit Background Color', 'premium_elementor' ),
				'type' 			=> Controls_Manager::COLOR,
				'scheme' 		=> [
				    'type' 	=> Scheme_Color::get_type(),
				    'value' => Scheme_Color::COLOR_1,
				],
				'selectors'		=> [
					'{{WRAPPER}} .countdown .pre_countdown-section .pre_countdown-amount' => 'background-color: {{VALUE}};'
				]
			]
		);

		$this->add_responsive_control(
			'digit_bg_size',
		  	[
		     	'label'			=> esc_html__( 'Digit Background Size', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::SLIDER,
		     	'default' => [
					'size' => 50,
				],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 200,
					]
				],
				'selectors'		=> [
					'{{WRAPPER}} .countdown .pre_countdown-section .pre_countdown-amount' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};'
				]
		  	]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'on_expire_settings',
			[
				'label' => esc_html__( 'Expire Settings' , 'premium_elementor' )
			]
		);

		$this->add_control(
			'expire_text_url',
			[
				'label'			=> esc_html__('Expire Text or redirection', 'premium_elementor'),
				'label_block'	=> false,
				'type'			=> Controls_Manager::SELECT,
				'options'		=> [
					'text'		=> esc_html__('Text', 'premium_elementor'),
					'url'		=> esc_html__('URL', 'premium_elementor')
				],
				'default'		=> 'text'
			]
		);

		$this->add_control(
			'expiry_text_',
			[
				'label'			=> esc_html__('On expiry Text', 'premium_elementor'),
				'type'			=> Controls_Manager::WYSIWYG,
				'default'		=> '<h1>Count Down is finished!</h1>',
				'condition'		=> [
					'expire_text_url' => 'text'
				]
			]
		);

		$this->add_control(
			'expiry_redirection_',
			[
				'label'			=> esc_html__('Redirect To', 'premium_elementor'),
				'type'			=> Controls_Manager::URL,
				'condition'		=> [
					'expire_text_url' => 'url'
				],
				'default'		=> [
					'url' 	=> get_permalink( 1 )
				]
			]
		);

		

		$this->end_controls_section();

		$this->start_controls_section(
			'pcdt_transaltion',
			[
				'label' => esc_html__( 'Transaltion Settings' , 'premium_elementor' )
			]
		);

		$this->add_control(
			'day_singular',
		  	[
		     	'label'			=> esc_html__( 'Day (Singular)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Day'
		  	]
		);

		$this->add_control(
			'day_plural',
		  	[
		     	'label'			=> esc_html__( 'Day (Plural)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Days'
		  	]
		);

		$this->add_control(
			'week_singular',
		  	[
		     	'label'			=> esc_html__( 'Week (Singular)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Week'
		  	]
		);

		$this->add_control(
			'week_plural',
		  	[
		     	'label'			=> esc_html__( 'Weeks (Plural)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Weeks'
		  	]
		);


		$this->add_control(
			'month_singular',
		  	[
		     	'label'			=> esc_html__( 'Month (Singular)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Month'
		  	]
		);


		$this->add_control(
			'month_plural',
		  	[
		     	'label'			=> esc_html__( 'Months (Plural)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Months'
		  	]
		);


		$this->add_control(
			'year_singular',
		  	[
		     	'label'			=> esc_html__( 'Year (Singular)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Year'
		  	]
		);


		$this->add_control(
			'year_plural',
		  	[
		     	'label'			=> esc_html__( 'Years (Plural)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Years'
		  	]
		);


		$this->add_control(
			'hour_singular',
		  	[
		     	'label'			=> esc_html__( 'Hour (Singular)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Hour'
		  	]
		);


		$this->add_control(
			'hour_plural',
		  	[
		     	'label'			=> esc_html__( 'Hours (Plural)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Hours'
		  	]
		);


		$this->add_control(
			'minute_singular',
		  	[
		     	'label'			=> esc_html__( 'Minute (Singular)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Minute'
		  	]
		);

		$this->add_control(
			'minute_plural',
		  	[
		     	'label'			=> esc_html__( 'Minutes (Plural)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Minutes'
		  	]
		);

		$this->add_control(
			'second_plural',
		  	[
		     	'label'			=> esc_html__( 'Seconds (Plural)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Seconds'
		  	]
		);

		$this->add_control(
			'second_singular',
		  	[
		     	'label'			=> esc_html__( 'Second (Singular)', 'premium_elementor' ),
		     	'type' 			=> Controls_Manager::TEXT,
		     	'default'		=> 'Second',
		     	'separator'		=> 'after'
		  	]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'pcdt_typhography',
			[
				'label' => esc_html__( 'Typhography Settings' , 'premium_elementor' ),
				'tab' 			=> Controls_Manager::TAB_STYLE
			]
		);

		$this->add_control(
			'digit_color',
			[
				'label' 		=> esc_html__( 'Timer Digit colors', 'premium_elementor' ),
				'type' 			=> Controls_Manager::COLOR,
				'scheme' 		=> [
				    'type' 	=> Scheme_Color::get_type(),
				    'value' => Scheme_Color::COLOR_2,
				],
				'selectors'		=> [
					'{{WRAPPER}} .countdown .pre_countdown-section .pre_countdown-amount' => 'color: {{VALUE}};'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'digit_typho',
				'scheme' => Scheme_Typography::TYPOGRAPHY_3,
				'selector' => '{{WRAPPER}} .countdown .pre_countdown-section .pre_countdown-amount',
				'separator'		=> 'after'
			]
		);

		$this->add_control(
			'unit_color',
			[
				'label' 		=> esc_html__( 'Timer Unit colors', 'premium_elementor' ),
				'type' 			=> Controls_Manager::COLOR,
				'scheme' 		=> [
				    'type' 	=> Scheme_Color::get_type(),
				    'value' => Scheme_Color::COLOR_2,
				],
				'selectors'		=> [
					'{{WRAPPER}} .countdown .pre_countdown-section .pre_countdown-period' => 'color: {{VALUE}};'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'unit_typho',
				'scheme' => Scheme_Typography::TYPOGRAPHY_3,
				'selector' => '{{WRAPPER}} .countdown .pre_countdown-section .pre_countdown-period',
				'separator'		=> 'after'
			]
		);

		$this->end_controls_section();
	}

	protected function render( ) {
		
      	$settings = $this->get_settings();

      	$target_date = $settings['pcdt_date_time'];
      	$formats = $settings['pcdt_units'];
      	$format = implode('', $formats );
      	$time = str_replace('-', '/', current_time('mysql') );
      	$serverSync = '';
      	if( $settings['pcdt_s_u_time'] == 'wp-time' ) : 
			$serverSync = 'serverSync : function() { return new Date(\'' .$time .'\') }';
		endif;

		$redirect = !empty( $settings['expiry_redirection_'] ) ? $settings['expiry_redirection_']['url'] : '';

      	// Singular labels set up
      	$y = !empty( $settings['year_singular'] ) ? $settings['year_singular'] : 'Year';
      	$m = !empty( $settings['month_singular'] ) ? $settings['month_singular'] : 'Month';
      	$w = !empty( $settings['week_singular'] ) ? $settings['week_singular'] : 'Week';
      	$d = !empty( $settings['day_singular'] ) ? $settings['day_singular'] : 'Day';
      	$h = !empty( $settings['hour_singular'] ) ? $settings['hour_singular'] : 'Hour';
      	$mi = !empty( $settings['minute_singular'] ) ? $settings['minute_singular'] : 'Minute';
      	$s = !empty( $settings['second_singular'] ) ? $settings['second_singular'] : 'Second';
      	$label = $y."," . $m ."," . $w ."," . $d ."," . $h ."," . $mi ."," . $s;

      	// Plural labels set up
      	$ys = !empty( $settings['year_plural'] ) ? $settings['year_plural'] : 'Years';
      	$ms = !empty( $settings['month_plural'] ) ? $settings['month_plural'] : 'Months';
      	$ws = !empty( $settings['week_plural'] ) ? $settings['week_plural'] : 'Weeks';
      	$ds = !empty( $settings['day_plural'] ) ? $settings['day_plural'] : 'Days';
      	$hs = !empty( $settings['hour_plural'] ) ? $settings['hour_plural'] : 'Hours';
      	$mis = !empty( $settings['minute_plural'] ) ? $settings['minute_plural'] : 'Minutes';
      	$ss = !empty( $settings['second_plural'] ) ? $settings['second_plural'] : 'Seconds';
      	$labels1 = $ys."," . $ms ."," . $ws ."," . $ds ."," . $hs ."," . $mis ."," . $ss;
      	$expire_text = $settings['expiry_text_'];

      	$expire_text = str_replace( "\\", "\\\\", $expire_text );
      	$expire_text = str_replace( '"', '\"', $expire_text );


      	$pcdt_style = $settings['pcdt-style'] == 'd-u-s' ? ' side' : ' down';
      	$border_style = $settings['timer_border_style'] .' border';
      	$unid = $this->get_id();
      	?>
			<div id="countDownContiner">
				<div class="countdown<?php echo $pcdt_style; ?> <?php echo $border_style; ?>" id="countdown-<?php echo $unid?>"></div>
			</div>
			<script>
				( function( $ ) {
					$(document).ready( function() {
						var label1 = '<?php echo $label; ?>',
							label2 = '<?php echo $labels1; ?>',
							newLabe1 = label1.split(','),
							newLabe2 = label2.split(',');
				
						$('#countdown-<?php echo $unid?>').pre_countdown({
							labels 		: newLabe2,
							labels1 	: newLabe1,
							until 		: new Date( '<?php echo $target_date; ?>'),
							format 		: '<?php echo $format; ?>',
							padZeroes	: true,
							<?php if( $settings['expire_text_url'] == 'text' ):  ?>
							onExpiry	: function() {
								$(this).html("<?php echo $expire_text; ?>");
							},
							<?php endif; ?>
							<?php if( $settings['expire_text_url'] == 'url' ):  ?>
							expiryUrl	: '<?php echo $redirect; ?>',
							<?php endif; ?>
							<?php echo $serverSync; ?>
						});
						times = $('#countdown-<?php echo $unid?>').pre_countdown('getTimes');
						function runTimer( el ) {
							return el == 0;
						}
						if( times.every( runTimer ) ) {
							<?php if( $settings['expire_text_url'] == 'text' ):  ?>
							$('#countdown-<?php echo $unid?>').html("<?php echo $expire_text; ?>");
							<?php endif; ?>
							<?php if( $settings['expire_text_url'] == 'url' ):  ?>
								var editMode = $('body').find('#elementor').length;
								if( editMode > 0 ) {
									$('#countdown-<?php echo $unid?>').html( '<h1>You can not redirect url from elementor Editor!!</h1>' );
								} else {
									window.location.href = '<?php echo $redirect; ?>';
								}
								
							<?php endif; ?>
						}
					});
					
					// On duplicate load everything on iframe load
					$('.elementor-element-overlay .elementor-editor-element-duplicate').on('click', function() {
						var $this = $(this);
							parentId = $this.parents('section.elementor-element');

						if( parentId.find('#countDownContiner').length ) {
							document.location.href = document.location.href;
						}
					
					});

				})( jQuery );
				
			</script>

      	<?php

    }


}

Plugin::instance()->widgets_manager->register_widget_type( new Premium_Counter_Down_Widget() );
