<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Premium_Image_Separator_Widget extends Widget_Base
{
    protected $templateInstance;

    public function getTemplateInstance() {
        return $this->templateInstance = premium_Template_Tags::getInstance();
    }

    public function get_name() {
        return 'premium-addon-image-separator';
    }

    public function get_title() {
        return esc_html__('Premium Image Separator', 'premium_elementor');
    }

    public function get_icon() {
        return 'pa-pa-image';
    }

    public function get_categories() {
        return [ 'premium-elements' ];
    }

    // Adding the controls fields for the premium image separator
    // This will controls the animation, colors and background, dimensions etc
    protected function _register_controls() {

        /* Start Content Section */
        $this->start_controls_section('premium_image_separator_general_settings',
                [
                    'label'         => esc_html__('General Settings', 'premium_elementor')
                    ]
                );
        
        /*Separator Image*/ 
        $this->add_control('premium_image_separator_image',
                [
                    'label'         => esc_html__('Image', 'premium_elementor'),
                    'type'          => Controls_Manager::MEDIA,
                    'default'       => [
                        'url'	=> Utils::get_placeholder_image_src(),
                        ],
                    'description'   => esc_html__('Choose the separator image', 'premium_elementor' ),
                    'label_block'   => true
                    ]
                );

        /*Separator Image Size*/
        $this->add_control('premium_image_separator_image_size',
                [
                    'label'         => esc_html__('Image Size', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', "em"],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-image-separator-container img' => 'width: {{SIZE}}{{UNIT}};'
                        ]
                    ]
                );
        
        /*Separator Image Gutter*/
        $this->add_control('premium_image_separator_image_gutter',
                [
                    'label'         => esc_html__('Image Gutter (%)', 'premium_elementor'),
                    'type'          => Controls_Manager::NUMBER,
                    'default'       => -50,
                    'description'   => esc_html__('-50% is default. Increase to push the image outside or decrease to pull the image inside.','premium_elementor'),
                    'label_block'   => true,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-image-separator-container' => 'transform: translateY( {{VALUE}}% );'
                        
                        ]
                    ]
                );
        
        /*Link Below Image*/
        $this->add_control('premium_image_separator_image_link_text',
                [
                    'label'         => esc_html__('URL Title', 'premium_elementor'),
                    'type'          => Controls_Manager::TEXT,
                    'label_block'   => true
                ]
                );
        
        /*Link Below Image*/
        $this->add_control('premium_image_separator_image_link',
                [
                    'label'         => esc_html__('URL', 'premium_elementor'),
                    'type'          => Controls_Manager::TEXT,
                    'label_block'   => true
                ]
                );
        
        /*Link Target*/ 
        $this->add_control('premium_image_separator_link_target',
                [
                    'label'         => esc_html__('Link Target', 'premium_elementor'),
                    'type'          => Controls_Manager::SELECT,
                    'description'   => esc_html__( 'Select link target', 'premium_elementor' ),
                    'options'       => [
                        'blank'  => esc_html('Blank'),
                        'parent' => esc_html('Parent'),
                        'self'   => esc_html('Self'),
                        'top'    => esc_html('Top'),
                        ],
                    'default'       => esc_html__('blank','premium_elementor')
                    ]
                );
       
        /*End Price Settings Section*/
        $this->end_controls_section();
       
    }

    protected function render($instance = [])
    {
        // get our input from the widget settings.
        $settings = $this->get_settings();
?>

<div class="premium-image-separator-container">
    
    <img alt="image separator" class="img-responsive" src="<?php echo $settings['premium_image_separator_image']['url']; ?>">
            <?php if ( !empty ( $settings['premium_image_separator_image_link_text'] ) ) : ?>
                <a class="premium-image-separator-link" href="<?php echo $settings['premium_image_separator_image_link']; ?>" target="_<?php echo $settings['premium_image_separator_link_target']; ?>" title="<?php echo $settings['premium_image_separator_image_link_text']; ?>">
                </a>
            <?php endif;?>
</div>
    <?php
    }
}
Plugin::instance()->widgets_manager->register_widget_type(new Premium_Image_Separator_Widget());
