<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Premium_Maps_Widget extends Widget_Base
{
    protected $templateInstance;

    public function getTemplateInstance() {
        return $this->templateInstance = premium_Template_Tags::getInstance();
    }

    public function get_name() {
        return 'premium-addon-maps';
    }

    public function get_title() {
        return esc_html__('Premium Maps', 'premium_elementor');
    }

    public function get_icon() {
        return 'pa-pa-post';
    }

    public function get_categories() {
        return [ 'premium-elements' ];
    }

    // Adding the controls fields for the premium maps
    // This will controls the animation, colors and background, dimensions etc
    protected function _register_controls() {

        /* Start Map Settings Section */
        $this->start_controls_section('premium_maps_map_settings',
                [
                    'label'         => esc_html__('Map Settings', 'premium_elementor')
                    ]
                );
        
        /*Map Pins*/
        $this->add_control('premium_maps_map_pins',
                [
                    'label'         => esc_html__('Map Pins', 'premium_elementor'),
                    'type'          => Controls_Manager::REPEATER,
                    'default'       => [
                        'map_address'   => esc_html__('London Eye, London, United Kingdom', 'premium_elementor'),
                        'map_title'     => esc_html__('Google Map', 'premium_elementor'),
                        'map_content'   => esc_html__('Add an optional title and description to your map pins', 'premium_elementor'),
                    ],
                    'fields'       => [
                        [
                            'name'          => 'map_address',
                            'label'         => esc_html__('Map Address', 'premium_elementor'),
                            'type'          => Controls_Manager::TEXT,
                            'label_block'   => true,
                            ],
                            [
                            'name'          => 'map_title',
                            'label'         => esc_html__('Pin Title', 'premium_elementor'),
                            'type'          => Controls_Manager::TEXT,
                            'label_block'   => true,
                            ],
                            [
                            'name'          => 'map_content',
                            'label'         => esc_html__('Pin Text', 'premium_elementor'),
                            'type'          => Controls_Manager::TEXTAREA,
                            'label_block'   => true,
                            ],
                            [
                            'name'          => 'map_marker_open',
                            'label'         => esc_html__('Automatically Open Pin', 'premium_elementor'),
                            'type'          => Controls_Manager::SWITCHER,
                            'label_block'   => true,
                            ],
                            [
                            'name'          => 'map_address_custom_pin',
                            'label'         => esc_html__('Custom Marker Icon', 'premium_elementor'),
                            'type'          => Controls_Manager::MEDIA,
                            ],
                        ],
                    'title_field'   => '<i class="fa fa-map-marker"></i> {{{ map_address }}}',
                    ]
                );
       
        /*End Map Settings Section*/
        $this->end_controls_section();
       
        /*Start Map Options Section*/
        $this->start_controls_section('premium_maps_map_options',
                [
                    'label'         => esc_html__('Map Options', 'premium_elementor'),
                ]
                );
        
        $this->add_responsive_control('premium_maps_map_height',
                [
                    'label'         => esc_html__( 'Map Height', 'premium_elementor' ),
                    'type'          => Controls_Manager::SLIDER,
                    'default'       => [
                            'size' => 500,
                    ],
                    'range'         => [
                            'px' => [
                                'min' => 80,
                                'max' => 1400,
                            ],
                    ],
                    'selectors'     => [
                            '{{WRAPPER}} .premium_maps_map_height' => 'height: {{SIZE}}px;',
                    ],
                ]
  		);
		
  		
		
        $this->add_control('premium_maps_map_zoom',
                [
                    'label'         => esc_html__( 'Map Zoom', 'premium_elementor' ),
                    'type'          => Controls_Manager::SLIDER,
                    'default'       => [
                        'size' => 12,
                    ],
                    'range'         => [
                        'px' => [
                                'min' => 0,
                                'max' => 22,
                        ],
                    ],
                ]
                );


        $this->add_control('premium_maps_map_option_single_pin',
                [
                    'label'         => esc_html__( 'Open One Pin at a Time?', 'premium_elementor' ),
                    'type'          => Controls_Manager::SWITCHER,
                ]
                );
		
        $this->add_control('premium_maps_map_option_streeview',
                [
                    'label'         => esc_html__( 'Street View Controls', 'premium_elementor' ),
                    'type'          => Controls_Manager::SWITCHER,
                ]
                );
		
		
		
        $this->add_control('premium_maps_map_option_maptype_control',
                [
                    'label'         => esc_html__( 'Map Type Controls Top Right', 'premium_elementor' ),
                    'type'          => Controls_Manager::SWITCHER,
                ]
                );
		
        $this->add_control('premium_maps_map_option_mapscroll',
                [
                    'label'         => esc_html__( 'Scroll Wheel Zoom', 'premium_elementor' ),
                    'type'          => Controls_Manager::SWITCHER,
                ]
                );
		
        $this->add_control('premium_maps_map_type',
                [
                    'label'         => esc_html__( 'Map Type', 'premium_elementor' ),
                    'type'          => Controls_Manager::SELECT,
                    'options'       => [
                        'roodmap'       => esc_html__( 'Road Map', 'premium_elementor' ),
                        'satellite'     => esc_html__( 'Satellite', 'premium_elementor' ),
                        'terrain'       => esc_html__( 'Terrain', 'premium_elementor' ),
                        'hybrid'        => esc_html__( 'Hybrid', 'premium_elementor' ),
                        ],
                    'default'       => 'roodmap',
                    ]
                );
                
        /*End Map Options Section*/
        $this->end_controls_section();
        
        /*Start Title Style Section*/
        $this->start_controls_section('premium_maps_pin_title_style',
                [
                    'label'         => esc_html__('Pin Title Style', 'premium_elementor'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                ]
                );
        
        /*Pin Title Color*/
        $this->add_control('premium_maps_pin_title_color',
                [
                    'label'         => esc_html__('Pin Title Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-maps-pin-title'   => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        $this->add_group_control(
        Group_Control_Typography::get_type(),
                [
                    'name'          => 'pin_title_typography',
                    'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                    'selector'      => '{{WRAPPER}} .premium-maps-pin-title',
                ]
                );
        
        /*Pin Title Padding*/
        $this->add_responsive_control('premium_maps_pin_title_padding',
                [
                    'label'         => esc_html__('Padding', 'premium_elementor'),
                    'type'          => Controls_Manager::DIMENSIONS,
                    'size_units'    => ['px', 'em', '%'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-maps-pin-title'   => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
                    ]
                );
        
        /*Pin Title ALign*/
        $this->add_responsive_control('premium_maps_pin_title_align',
                [
                    'label'         => esc_html__( 'Text Align', 'elementor' ),
                    'type'          => Controls_Manager::CHOOSE,
                    'options'       => [
                        'left'      => [
                            'title'=> esc_html__( 'Left', 'elementor' ),
                            'icon' => 'fa fa-align-left',
                            ],
                        'center'    => [
                            'title'=> esc_html__( 'Center', 'elementor' ),
                            'icon' => 'fa fa-align-center',
                            ],
                        'right'     => [
                            'title'=> esc_html__( 'Right', 'elementor' ),
                            'icon' => 'fa fa-align-right',
                            ],
                        ],
                    'default'       => 'center',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-maps-pin-title' => 'text-align: {{VALUE}};',
                        ],
                    ]
                );
                
        /*End Title Style Section*/
        $this->end_controls_section();
        
        /*Start Pin Style Section*/
        $this->start_controls_section('premium_maps_pin_text_style',
                [
                    'label'         => esc_html__('Pin Text Style', 'premium_elementor'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                ]
                );
        
        $this->add_control('premium_maps_pin_text_color',
                [
                    'label'         => esc_html__('Pin Description Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-maps-pin-text'   => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        $this->add_group_control(
        Group_Control_Typography::get_type(),
                [
                    'name'          => 'pin_text_typo',
                    'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                    'selector'      => '{{WRAPPER}} .premium-maps-pin-text',
                ]
                );
        
        $this->add_responsive_control('premium_maps_pin_text_padding',
                [
                    'label'         => esc_html__('Padding', 'premium_elementor'),
                    'type'          => Controls_Manager::DIMENSIONS,
                    'size_units'    => ['px', 'em', '%'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-maps-pin-text'   => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                        ]
                    ]
                );
        
        /*Pin Title ALign*/
        $this->add_responsive_control('premium_maps_pin_description_align',
                [
                    'label'         => esc_html__( 'Text Align', 'elementor' ),
                    'type'          => Controls_Manager::CHOOSE,
                    'options'       => [
                        'left'      => [
                            'title'=> esc_html__( 'Left', 'elementor' ),
                            'icon' => 'fa fa-align-left',
                            ],
                        'center'    => [
                            'title'=> esc_html__( 'Center', 'elementor' ),
                            'icon' => 'fa fa-align-center',
                            ],
                        'right'     => [
                            'title'=> esc_html__( 'Right', 'elementor' ),
                            'icon' => 'fa fa-align-right',
                            ],
                        ],
                    'default'       => 'center',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-maps-pin-text h6' => 'text-align: {{VALUE}};',
                        ],
                    ]
                );
        
        /*End Pin Style Section*/
        $this->end_controls_section();
    }

    protected function render($instance = [])
    {
        // get our input from the widget settings.
        $settings = $this->get_settings();
?>
    <div class="premium-maps-container">
        <div id="premium-maps-map-<?php echo esc_attr($this->get_id()); ?>" class="premium_maps_map_height"></div>
    </div>
	<script type="text/javascript"> 
	jQuery(document).ready(function($) {
            'use strict';
            $("#premium-maps-map-<?php echo esc_attr($this->get_id()); ?>").goMap({
                <?php if ( ! empty( $settings['map_center_address'] ) ) : ?>address: '<?php echo esc_attr($settings['map_center_address'] ); ?>',<?php endif; ?>
                markers: [
                    <?php foreach ( $settings['premium_maps_map_pins'] as $item ) : ?>{
                            address: '<?php echo esc_attr( $item['map_address'] ); ?>">',
                                    <?php if ( ! empty( $item['map_address_custom_pin'] ) ) : ?>
                                    icon: '<?php $image = $item['map_address_custom_pin']; $imageurl = wp_get_attachment_image_src($image['id'], 'large'); ?><?php echo esc_attr($imageurl[0]);?>',<?php endif; ?>
                                    <?php if ( ! empty( $item['map_title'] ) ) : ?>
                                    html: {content: "<div class='premium-maps-map-pin'><h6 class='premium-maps-pin-title'><?php echo esc_attr($item['map_title'] ); ?></h6><div class='premium-maps-pin-text'><h6><?php echo wp_kses( __($item['map_content'] ), true); ?></h6></div></div>", 
                                    popup:<?php if ( ! empty( $item['map_marker_open'] ) ) : ?>true<?php else: ?>false<?php endif; ?>}<?php endif; ?>},
                <?php endforeach; ?>
		],
		scrollwheel: <?php if ( ! empty( $settings['premium_maps_map_option_mapscroll'] ) ) : ?>true<?php else: ?>false<?php endif; ?>,  disableDoubleClickZoom: false, zoom: <?php $width = $this->get_settings( 'premium_maps_map_zoom' );  echo esc_attr($width['size']);  ?>, maptype: '<?php echo esc_attr($settings['premium_maps_map_type'] ); ?>', streetViewControl:<?php if ( ! empty( $settings['premium_maps_map_option_streeview'] ) ) : ?>true<?php else: ?>false<?php endif; ?>, oneInfoWindow: <?php if ( ! empty( $settings['premium_maps_map_option_single_pin'] ) ) : ?>true<?php else: ?>false<?php endif; ?>, mapTypeControl:<?php if ( ! empty( $settings['premium_maps_map_option_maptype_control'] ) ) : ?>true<?php else: ?>false<?php endif; ?>	
    });
	});
	</script>


    <?php
    }
}
Plugin::instance()->widgets_manager->register_widget_type(new Premium_Maps_Widget());
