<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Premium_Testimonials_Widget extends Widget_Base
{
    protected $templateInstance;

    public function getTemplateInstance() {
        return $this->templateInstance = premium_Template_Tags::getInstance();
    }

    public function get_name() {
        return 'premium-addon-testimonials';
    }

    public function get_title() {
        return esc_html__('Premium Testimonial', 'premium_elementor');
    }

    public function get_icon() {
        return 'pa-pa-chat';
    }

    public function get_categories() {
        return [ 'premium-elements' ];
    }

    // Adding the controls fields for the premium testimonial
    // This will controls the animation, colors and background, dimensions etc
    protected function _register_controls() {   
        /*Testimonials Content Section */
        $this->start_controls_section('premium_testimonial_person_settings',
                [
                    'label'             => esc_html__('Person Content Section', 'premium_elementor'),
                    ]
                );
        
        /*Person Image*/
        $this->add_control('premium_testimonial_person_image',
                [
                    'label'             => esc_html__('Person Image','premium_elementor'),
                    'type'              => Controls_Manager::MEDIA,
                    'default'           => [
                        'url' => 'https://image.freepik.com/free-icon/male-user-silhouette_318-35708.jpg',
                        ],
                    'description'       => esc_html__( 'Choose an image for the author.', 'premium_elementor' ),
                    'show_label'        => true,
                    ]
                );        

        /*Person Image Shape*/
        $this->add_control('premium_testimonial_person_image_shape',
                [
                    'label'             => esc_html__('Image style.', 'premium_elementor'),
                    'type'              => Controls_Manager::SELECT,
                    'description'       => esc_html__( 'Choose image style.', 'premium_elementor' ),
                    'options'           => [
                        'square'  => esc_html__('Square'),
                        'circle'  => esc_html__('Circle'),
                        'rounded' => esc_html__('Rounded'),
                        ],
                    'default'           => 'circle',
                    ]
                );
        
        /*Person Name*/ 
        $this->add_control('premium_testimonial_person_name',
                [
                    'label'             => esc_html__('Person Name', 'premium_elementor'),
                    'type'              => Controls_Manager::TEXTAREA,
                    'default'           => esc_html__('Person Name', 'premium_elementor'),
                    'description'       => esc_html__( 'Enter author name.', 'premium_elementor' ),
                    'label_block'       => true
                    ]
                );
        
        /*Front Title Tag*/
        $this->add_control('premium_testimonial_person_name_size',
                [
                    'label'             => esc_html__('Name Tag', 'premium_elementor'),
                    'type'              => Controls_Manager::SELECT,
                    'description'       => esc_html__( 'Select a heading tag for author name.', 'premium_elementor' ),
                    'options'           => [
                        'h1' => esc_html('H1'),
                        'h2' => esc_html('H2'),
                        'h3' => esc_html('H3'),
                        'h4' => esc_html('H4'),
                        'h5' => esc_html('H5'),
                        'h6' => esc_html('H6'), 
                        ],
                    'default'           => esc_html__('h3','premium_elementor'),
                    'label_block'       => true,
                    ]
                );
        
        /*End Person Content Section*/
        $this->end_controls_section();

        /*Start Company Content Section*/       
        $this->start_controls_section('premium_testimonial_company_settings',
                [
                    'label'             => esc_html__('Company Content Section', 'premium_elementor')
                    ]
                );
        
        /*Company Name*/
        $this->add_control('premium_testimonial_company_name',
                [
                    'label'             => esc_html__('Company Name', 'premium_elementor'),
                    'type'              => Controls_Manager::TEXTAREA,
                    'default'           => esc_html__('Company Name','premium_elementor'),
                    'description'       => esc_html__( 'Enter company name.', 'premium_elementor' ),
                    'label_block'       => true,
                    ]
                );
        
        /*Company Link */
        $this->add_control('premium_testimonial_company_link',
                [
                    'label'              => esc_html__('Company Link', 'premium_elementor'),
                    'type'               => Controls_Manager::TEXTAREA,
                    'description'        => esc_html__( 'Add company URL.', 'premium_elementor' ),
                    'label_block'        => true,
                    ]
                );
        
        /*Link Target*/ 
        $this->add_control('premium_testimonial_link_target',
                [
                    'label'             => esc_html__('Link Target', 'premium_elementor'),
                    'type'              => Controls_Manager::SELECT,
                    'description'       => esc_html__( 'Select link target', 'premium_elementor' ),
                    'options'           => [
                        'blank'  => esc_html__('Blank'),
                        'parent' => esc_html__('Parent'),
                        'self'   => esc_html__('Self'),
                        'top'    => esc_html__('Top'),
                        ],
                    'default'           => esc_html__('blank','premium_elementor'),
                    ]
                );
        
        /*End Company Content Section*/
        $this->end_controls_section();

        /*Start Testimonial Content Section*/
        $this->start_controls_section('premium_testimonial_settings',
            [
                'label'                 => esc_html__('Testimonial Text Section', 'premium_elementor'),
            ]
        );

        /*Testimonial Content*/
        $this->add_control('premium_testimonial_content',
                [    
                    'label'             => esc_html__('Testimonial Content', 'premium_elementor'),
                    'type'              => Controls_Manager::WYSIWYG,
                    'default'           => esc_html__('Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.','premium-elementor'),
                    'label_block'       => true,
                    ]
                );

        /*End Testimonial Content Section*/
        $this->end_controls_section();

        /*Start General Settings Section*/
        $this->start_controls_section('premium_testimonial_box_settings',
            [
                'label'                 => esc_html__('General Settings', 'premium_elementor'),
                'tab'                   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        /*Box Height*/
        $this->add_control('premium_testimonial_box_height',
                [
                    'label'             => esc_html__('Box Height', 'premium_elementor'),
                    'type'              => Controls_Manager::SLIDER,
                    'size_units'        => ['px','em'],
                    'default'           => [
                        'size' => 270, 
                        ],
                    'range'             => [
                        'px'    => [
                            'min' => 20,
                            'max' => 1000,
                            ],
                        'em'    => [
                            'min'   => 1,
                            'max'   => 100,
                        ],    
                    ],
                    'selectors'         => [
                        '{{WRAPPER}} .premium-testimonial-Box'=> 'min-height: {{SIZE}}{{UNIT}};',
                        ]
                    ]
                );
        
        $this->start_controls_tabs( 'premium_testimonials_box' );
        
        $this->start_controls_tab('premium_testimonials_normal',
            [
                'label'             => esc_html__('Normal', 'premium_elementor'),
            ]
            );
        
        /*Box Background*/
        $this->add_group_control(
            Group_Control_Background::get_type(),
                [
                    'name'          => 'premium_testimonials_back',
                    'types'         => [ 'classic', 'gradient' ],
                    'selector'      => '{{WRAPPER}} .premium-testimonial-Box',
                ]
                );
        
        $this->add_group_control(
            Group_Control_Border::get_type(), 
                [
                    'name'          => 'premium_testimonials_border',
                    'selector'      => '{{WRAPPER}} .premium-testimonial-Box',
                ]
                );
        
        $this->add_control('premium_testimonials_border_radius',
                [
                    'label'         => esc_html__('Border Radius', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%' ,'em'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-testimonial-Box' => 'border-radius: {{SIZE}}{{UNIT}};'
                    ]
                ]
                );
        
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
                [
                    'name'          => 'premium_testimonials_shadow',
                    'selector'      => '{{WRAPPER}} .premium-testimonial-Box',
                ]
                );
        
        $this->end_controls_tab();
        
        $this->start_controls_tab('premium_testimonials_hover',
            [
                'label'             => esc_html__('Hover', 'premium_elementor'),
            ]
            );
        
        /*Box Background*/
        $this->add_group_control(
            Group_Control_Background::get_type(),
                [
                    'name'          => 'premium_testimonials_back_hover',
                    'types'         => [ 'classic', 'gradient' ],
                    'selector'      => '{{WRAPPER}} .premium-testimonial-Box:hover',
                ]
                );
        
        $this->add_group_control(
            Group_Control_Border::get_type(), 
                [
                    'name'          => 'premium_testimonials_border_hover',
                    'selector'      => '{{WRAPPER}} .premium-testimonial-Box:hover',
                ]
                );
        
        $this->add_control('premium_testimonials_border_radius_hover',
                [
                    'label'         => esc_html__('Border Radius', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%' ,'em'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-testimonial-Box:hover' => 'border-radius: {{SIZE}}{{UNIT}};'
                    ]
                ]
                );
        
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
                [
                    'name'          => 'premium_testimonials_shadow_hover',
                    'selector'      => '{{WRAPPER}} .premium-testimonial-Box:hover',
                ]
                );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();

        /*End General Settings Section*/
        $this->end_controls_section();
        
        /*Image Styling*/
        $this->start_controls_section('premium_testimonial_image_style',
            [
                'label'             => esc_html__('Image settings', 'premium_elementor'),
                'tab'               => Controls_Manager::TAB_STYLE, 
                ]
            );
        
        /*Image Size*/
        $this->add_control('premium_testimonial_img_size',
                [
                    'label'             => esc_html__('Image Size', 'premium_elementor'),
                    'type'              => Controls_Manager::SLIDER,
                    'size_units'        => ['px', 'em'],
                    'default'           => [
                        'unit'  =>  'px',
                        'size'  =>  75,
                        ],
                    'range'             => [
                        'px'=> [
                            'min' => 10,
                            'max' => 150,
                        ]
                        ],
                    'selectors'         => [
                        '{{WRAPPER}} .premium-testimonial-img-wrapper'=> 'width: {{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}};',
                        ]
                    ]
                );

        /*Image Border Width*/
        $this->add_control('premium_testimonial_img_border_width',
                [
                    'label'             => esc_html__('Image Border Width (PX)', 'premium_elementor'),
                    'type'              => Controls_Manager::SLIDER,
                    'default'           => [
                        'unit'  => 'px',
                        'size'  =>  2,
                        ],
                    'range'             => [
                        'px'=> [
                            'min' => 0,
                            'max' => 15,
                            ]
                        ],
                    'selectors'         => [
                        '{{WRAPPER}} .premium-testimonial-person-image' => 'border-width: {{SIZE}}{{UNIT}};',
                        ]
                    ]
                );
        
        /*Image Border Color*/
        $this->add_control('premium_testimonial_image_border_color',
             [
                'label'                 => esc_html__('Image Border Color', 'premium_elementor'),
                'type'                  => Controls_Manager::COLOR,
                'default'               => '#6ec1e4',
                 'selectors'            => [
                    '{{WRAPPER}} .premium-testimonial-img-wrapper' => 'color: {{VALUE}};',
                ]
            ]
        );
        
        $this->end_controls_section();
        
        /*Start Quotes Style Section*/
        $this->start_controls_section('premium_testimonial_quotes',
                [
                    'label'             => esc_html__('Quotes settings', 'premium_elementor'),
                    'tab'               => Controls_Manager::TAB_STYLE,
                ]
                );
        
        /*Quotes Color*/ 
        $this->add_control('premium_testimonial_quote_icon_color',
                [
                   'label'              => esc_html__('Quotes Color','premium_elementor'),
                   'type'               => Controls_Manager::COLOR,
                   'default'            => '#6ec1e4',
                    'selectors'         =>  [
                        '{{WRAPPER}} .fa'   =>  'color: {{VALUE}};',
                        ]
                    ]
                );

        /*Quotes Size*/
        $this->add_control('premium_testimonial_quotes_size',
                [
                    'label'             => esc_html__('Quotes Size', 'premium_elementor'),
                    'type'              => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'default'           => [
                        'unit'  => 'px',
                        'size'  => 120,
                        ],
                    'range'             => [
                        'px' => [
                            'min' => 5,
                            'max' => 250,
                            ]
                        ],
                    'selectors'         => [
                        '{{WRAPPER}} .premium-testimonial-upper-quote, {{WRAPPER}} .premium-testimonial-lower-quote' => 'font-size: {{SIZE}}{{UNIT}};',
                        ]
                    ]
                );
        
        /*Upper Quote Position*/
        $this->add_control('premium_testimonial_upper_quote_position',
                [
                    'label'             => esc_html__('Upper Quote Position', 'premium_elementor'),
                    'type'              => Controls_Manager::DIMENSIONS,
                    'size_units'            => ['px', 'em', '%'],
                    'default'           =>[
                        'top'   =>  50,
                        'left'  =>  12 ,
                        'unit'  =>  'px',
                        ],
                    'selectors'         => [
                        '{{WRAPPER}} .premium-testimonial-upper-quote' => 'top: {{TOP}}{{UNIT}}; left:{{LEFT}}{{UNIT}};',
                        ]
                    ]
                );
        
        /*Lower Quote Position*/
        $this->add_control('premium_testimonial_lower_quote_position',
                [
                    'label'             => esc_html__('Lower Quote Position', 'premium_elementor'),
                    'type'              => Controls_Manager::DIMENSIONS,
                    'size_units'        => ['px', 'em', '%'],
                    'default'           =>[
                        'bottom'    =>  3,
                        'right'     =>  12,
                        'unit'      =>  'px',
                        ],
                    'selectors'         => [
                        '{{WRAPPER}} .premium-testimonial-lower-quote' => 'right: {{RIGHT}}{{UNIT}}; bottom: {{BOTTOM}}{{UNIT}};',
                        ]
                    ]
                );

        /*End Typography Section*/
        $this->end_controls_section();   
        
        /*Start Content Settings Section*/
        $this->start_controls_section('premium_testimonial_content_style',
                [
                    'label'             => esc_html__('Testimonial Content Settings', 'premium_elementor'),
                    'tab'               => Controls_Manager::TAB_STYLE, 
                ]
                );

        /*Content Color*/
        $this->add_control('premium_testimonial_content_color',
                [
                    'label'             => esc_html__('Testimonial Text Color', 'premium_elementor'),
                    'type'              => Controls_Manager::COLOR,
                    'default'           => '#7a7a7a',
                    'selectors'         => [
                        '{{WRAPPER}} .premium-testimonial-text-wrapper' => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Content Typography*/
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'          => 'content_typography',
                    'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                    'selector'      => '{{WRAPPER}} .premium-testimonial-text-wrapper',
                ]
                ); 
        
        
        /*Testimonial Text Margin*/
        $this->add_control('premium_testimonial_margin',
            [
                'label'                 => esc_html__('Testimonial Text Margin', 'premium_elementor'),
                'type'                  => Controls_Manager::DIMENSIONS,
                'size_units'            => ['px', 'em', '%'],
                'default'               =>[
                    'top'   =>  15,
                    'bottom'=>  15,
                    'left'  =>  0 ,
                    'right' =>  0 ,
                    'unit'  => 'px',
                    ],
                'selectors'             => [
                    '{{WRAPPER}} .premium-testimonial-text-wrapper' => 'margin: {{top}}{{UNIT}} {{right}}{{UNIT}} {{bottom}}{{UNIT}} {{left}}{{UNIT}};',
                    ]
                ]
                );

        /*End Content Settings Section*/
        $this->end_controls_section();
        
        /*Start Person Settings Section*/
        $this->start_controls_section('premium_testimonials_person_style', 
            [
                'label'                 => esc_html__('Person name settings', 'premium_elementor'),
                'tab'                   => Controls_Manager::TAB_STYLE, 
            ]
            );
        
        /*Person Name Color*/
        $this->add_control('premium_testimonial_person_name_color',
                [
                    'label'             => esc_html__('Person Name Color', 'premium_elementor'),
                    'type'              => Controls_Manager::COLOR,
                    'default'           => '#6ec1e4',
                    'selectors'         => [
                        '{{WRAPPER}} .premium-testimonial-person-name' => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Separator Color*/
        $this->add_control('premium_testimonial_separator_color',
                [
                    'label'             => esc_html__('Separator Color', 'premium_elementor'),
                    'type'              => Controls_Manager::COLOR,
                    'default'           => '#7a7a7a',
                    'selectors'         => [
                        '{{WRAPPER}} .premium-testimonial-separator' => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Authohr Name Typography*/
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'          => 'author_name_typography',
                    'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                    'selector'      => '{{WRAPPER}} .premium-testimonial-person-name',
                ]
                );
        
        $this->end_controls_section();
        
        /*Start Company Settings Section*/
        $this->start_controls_section('premium_testimonial_company_style',
                [
                    'label'             => esc_html__('Company name settings', 'premium_elementor'),
                    'tab'               => Controls_Manager::TAB_STYLE, 
                ]
                );

        /*Company Name Color*/
        $this->add_control('premium_testimonial_company_name_color',
                [
                    'label'             => esc_html__('Company Name Color', 'premium_elementor'),
                    'type'              => Controls_Manager::COLOR,
                    'default'           => '#7a7a7a',
                    'selectors'         => [
                        '{{WRAPPER}} .premium-testimonial-company-link' => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Company Typography*/
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'          => 'company_name_typography',
                    'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                    'selector'      => '{{WRAPPER}} .premium-testimonial-company-link',
                ]
                ); 

        /*End Color Section*/
        $this->end_controls_section();

    }

    protected function render($instance = [])
    {
        // get our input from the widget settings.
        $settings = $this->get_settings();

        $person_title_tag = $settings['premium_testimonial_person_name_size'];
?>
    
<!-- Testimonial Box Wrapper -->
<div class="premium-testimonial-Box">
    <div class="premium-testimonial-container">
        <i class="fa fa-quote-left premium-testimonial-upper-quote"></i>
        <!-- Testimonial Body Wrapper -->
        <div class="premium-testimonial-content-wrapper">
            <!-- Image Wrapper -->
            <div class="premium-testimonial-img-wrapper" style="border-radius: <?php 
            if( $settings['premium_testimonial_person_image_shape'] === 'circle' ) : echo "50%;";
            elseif ( $settings['premium_testimonial_person_image_shape'] === 'square' ) : echo "0;";
            elseif ( $settings['premium_testimonial_person_image_shape'] === 'rounded' ) : echo "15px;";
            endif;?>">
                 <img src="<?php echo $settings['premium_testimonial_person_image']['url']; ?>" alt="<?php echo $settings['premium_testimonial_person_name']; ?>" class="premium-testimonial-person-image" 
                    style="border-radius: <?php
                    if ( $settings['premium_testimonial_person_image_shape'] === 'circle' ) : echo "50%;";
                    elseif ( $settings['premium_testimonial_person_image_shape'] === 'square' ) : echo "0;";
                    elseif ( $settings['premium_testimonial_person_image_shape'] === 'rounded' ) : echo "15px;";
                    endif; ?>">
            </div>
        
            <!-- Testimonial Text Wrapper -->
            <div class="premium-testimonial-text-wrapper">
                <?php echo $settings['premium_testimonial_content']; ?>
            </div>
        
            <!-- Person Name & Separator & Company Name--> 
            <span class="premium-testimonial-author-info">
                <<?php echo $person_title_tag; ?> class="premium-testimonial-person-name"><?php echo $settings['premium_testimonial_person_name']; ?> </<?php echo $person_title_tag; ?>><span class="premium-testimonial-separator"> - </span><a class="premium-testimonial-company-link" href="<?php echo $settings['premium_testimonial_company_link']; ?>" target="_<?php echo $settings['premium_testimonial_link_target']; ?>"><span><?php echo $settings['premium_testimonial_company_name']; ?></span></a>
            </span>
        </div>
    
        <i class="fa fa-quote-right premium-testimonial-lower-quote"></i>
    </div>
</div>
    <?php
    }
}
Plugin::instance()->widgets_manager->register_widget_type(new Premium_Testimonials_Widget());
